@@ -7,7 +7,7 @@ factor_to_character <- function(data, warn = FALSE) {
 raw_to_character <- function(data) {
   is_raw <- vapply(data, is.raw, TRUE)
   if (any(is_raw)) {
-    wrn("Creating a TEXT column from raw, use lists of raw to create BLOB columns")
+    wrn("Creating a TEXT column from raw, use lists of raw to create BLOB columns.")
     data[is_raw] <- lapply(data[is_raw], as.character)
   }
   data
@@ -15,8 +15,13 @@ raw_to_character <- function(data) {
 
 sfc_to_blob <- function(data) {
   is_sfc <- vapply(data, is.sfc, TRUE)
-  data[is_sfc] <- lapply(data[is_sfc], sf::st_as_binary, 
-                         endian = "little")
+  if (any(is_sfc) && !requireNamespace("sf")) {
+    err("Package 'sf' must be installed.")
+  }
+
+  data[is_sfc] <- lapply(data[is_sfc], sf::st_as_binary,
+    endian = "little"
+  )
   data
 }
 
@@ -33,4 +38,4 @@ convert_data <- function(data) {
   data <- character_to_utf8(data)
   data <- sfc_to_blob(data)
   data
-}
\ No newline at end of file
+}
